module.exports = {
    id: 'button-rectangle',
    name: '@studapart/components-button-rectangle',
    title: 'Button rectangle',
    className: 'ButtonRectangle',
    group: 'Buttons',
    structure: {
        twig: {
            dom: '{% include component("button-rectangle") with {\n ${props}\n} %}'
        },
        vue: {
            dom: '<button-rectangle :class="dataClasses" ${props}>\n <!-- slots -->\n</button-rectangle>'
        }
    },
    modifiers: {
        options: ['red', 'green', 'blue', 'berry', 'cherry', 'papaya', 'loading', 'light', 'rounded', 'bordered', 'square-m', 's', 'xs', 'auto', 'full', 'disabled', 'inner-link', 'square-xs']
    },
    props: {
        text: {
            type: 'String', vue: true, twig: true,
            description: 'The content of the button.'
        },
        tag: {
            type: 'String', vue: true, twig: true,
            default: 'a',
            options: ['a', 'button', 'div'],
            description: 'The type of the button.'
        },
        href: {
            type: 'String', vue: true, twig: true,
            default: 'false',
            description: 'The url of the button.'
        },
        target: {
            type: 'String', vue: true, twig: true,
            default: 'false',
            options: ['_blank'],
            description: 'The target attribute of the button.'
        },
        fa: {
            type: 'String', vue: true, twig: true,
            description: 'FontAwesome icon name.'
        },
        icon: {
            type: 'Object', vue: true, twig: true,
            options: [
                { name: String, width: Number }
            ],
            description: 'Config object for an icon (placed after text).'
        },
        download: {
            type: 'Boolean', vue: true, twig: true,
            default: 'false',
            description: 'The download attribute of the button.'
        },
        isLoading: {
            type: 'Boolean', vue: true, twig: false,
            default: 'false',
            description: 'Loader animation.'
        }
    },
    examples: [
        {
            id: 'default',
            title: 'Default button',
            modifiers: ['green', 's'],
            props: {
                text: 'Voir le logement',
                tag: 'button'
            }
        },
        {
            id: 'loading',
            title: 'Loading button',
            modifiers: ['green', 's', 'loading'],
            props: {
                text: 'Voir le logement',
                tag: 'button'
            }
        },
        {
            id: 'brand',
            title: 'Rounded button',
            modifiers: ['rounded', 'bordered'],
            props: {
                text: `Commencer`,
                target: '_blank',
                href: 'http://www.google.com'
            }
        },
        {
            id: 'icon',
            title: 'Button with an icon',
            modifiers: ['green'],
            slots: {
                default: '<icon name="arrow-thin" :width="8" class="fill-ft-light ml-10"/>'
            },
            props: {
                text: 'Voir plus',
                tag: 'button',
                icon: {
                    name: "arrow-thin",
                    width: 8,
                    classes: ["fill-ft-light", "ml-10"]
                }
            }
        }
    ]
}